@@ -55,6 +55,7 @@ frozen = __get_is_frozen()
 base_path = __get_base_path()
 support_dir = __get_support_directory()
 
+offline = None #whether the context of the command is offline (for example, parsing, which should not require an sfdc session)
 plugin_client_settings = None
 connection = None
 project = None
@@ -68,5 +69,5 @@ osx_platforms = ["darwin"]
 user_platform = sys.platform
 
 is_windows   = user_platform in windows_platforms
-is_linux     = user_platform in windows_platforms
-is_osx       = user_platform in windows_platforms
+is_linux     = user_platform in linux_platforms
+is_osx       = user_platform in osx_platforms
